import * as i0 from '@angular/core';
import { Directive, EventEmitter, Input, Output, NgModule } from '@angular/core';
import { SubscribableDirective } from 'ngx-subscribable';
import { fromEvent } from 'rxjs';
import { filter } from 'rxjs/operators';

class AutofocusDirective extends SubscribableDirective {
    constructor(hostRef) {
        super();
        this.hostRef = hostRef;
    }
    ngAfterViewInit() {
        const host = this.hostRef.nativeElement;
        setTimeout(() => host.focus());
    }
}
AutofocusDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: AutofocusDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
AutofocusDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.2", type: AutofocusDirective, selector: "\n        sl-input[autofocus],\n        sl-textarea[autofocus],\n    ", usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: AutofocusDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-input[autofocus],
        sl-textarea[autofocus],
    `,
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; } });

function observe(element, eventName) {
    return fromEvent(element, eventName).pipe(filter((event) => (event === null || event === void 0 ? void 0 : event.target) === element));
}

class OpenDirective extends SubscribableDirective {
    constructor(hostRef) {
        super();
        this.hostRef = hostRef;
        this.open = false;
        this.openChange = new EventEmitter();
    }
    ngOnInit() {
        const host = this.hostRef.nativeElement;
        this.subscriptions = [
            observe(host, "sl-after-show").subscribe(() => this.changeOpen(true)),
            observe(host, "sl-after-hide").subscribe(() => this.changeOpen(false)),
        ];
    }
    ngOnChanges(changes) {
        if (changes.open)
            this.hostRef.nativeElement.open = changes.open.currentValue;
    }
    changeOpen(value) {
        this.open = value;
        this.openChange.emit(value);
    }
}
OpenDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: OpenDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
OpenDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.2", type: OpenDirective, selector: "\n        sl-alert[open],\n        sl-color-picker[open],\n        sl-details[open],\n        sl-dialog[open],\n        sl-drawer[open],\n        sl-dropdown[open],\n        sl-tooltip[open],\n    ", inputs: { open: "open" }, outputs: { openChange: "openChange" }, usesInheritance: true, usesOnChanges: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: OpenDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-alert[open],
        sl-color-picker[open],
        sl-details[open],
        sl-dialog[open],
        sl-drawer[open],
        sl-dropdown[open],
        sl-tooltip[open],
    `,
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { open: [{
                type: Input
            }], openChange: [{
                type: Output
            }] } });

class OpenableDirective extends SubscribableDirective {
    constructor(hostRef) {
        super();
        this.hostRef = hostRef;
        this.show = new EventEmitter();
        this.hide = new EventEmitter();
        this.afterShow = new EventEmitter();
        this.afterHide = new EventEmitter();
    }
    ngOnInit() {
        const host = this.hostRef.nativeElement;
        this.subscriptions = [
            observe(host, "sl-show").subscribe(event => this.show.emit(event)),
            observe(host, "sl-hide").subscribe(event => this.hide.emit(event)),
            observe(host, "sl-after-show").subscribe(event => this.afterShow.emit(event)),
            observe(host, "sl-after-hide").subscribe(event => this.afterHide.emit(event)),
        ];
    }
}
OpenableDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: OpenableDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
OpenableDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.2", type: OpenableDirective, selector: "\n        sl-alert,\n        sl-details,\n        sl-dialog,\n        sl-drawer,\n        sl-dropdown,\n        sl-tooltip,\n    ", outputs: { show: "show", hide: "hide", afterShow: "afterShow", afterHide: "afterHide" }, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: OpenableDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-alert,
        sl-details,
        sl-dialog,
        sl-drawer,
        sl-dropdown,
        sl-tooltip,
    `,
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { show: [{
                type: Output
            }], hide: [{
                type: Output
            }], afterShow: [{
                type: Output
            }], afterHide: [{
                type: Output
            }] } });
class OpenableExtendedDirective extends SubscribableDirective {
    constructor(hostRef) {
        super();
        this.hostRef = hostRef;
        this.initialFocus = new EventEmitter();
        this.requestClose = new EventEmitter();
    }
    ngOnInit() {
        const host = this.hostRef.nativeElement;
        this.subscriptions = [
            observe(host, "sl-initial-focus").subscribe(event => this.initialFocus.emit(event)),
            observe(host, "sl-request-close").subscribe(event => this.requestClose.emit(event)),
        ];
    }
}
OpenableExtendedDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: OpenableExtendedDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
OpenableExtendedDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.2", type: OpenableExtendedDirective, selector: "\n        sl-dialog,\n        sl-drawer,\n    ", outputs: { initialFocus: "initialFocus", requestClose: "requestClose" }, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: OpenableExtendedDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-dialog,
        sl-drawer,
    `,
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { initialFocus: [{
                type: Output
            }], requestClose: [{
                type: Output
            }] } });

class ShoelaceModule {
}
ShoelaceModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: ShoelaceModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ShoelaceModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.2", ngImport: i0, type: ShoelaceModule, declarations: [AutofocusDirective,
        OpenableDirective,
        OpenableExtendedDirective,
        OpenDirective], exports: [AutofocusDirective,
        OpenableDirective,
        OpenableExtendedDirective,
        OpenDirective] });
ShoelaceModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: ShoelaceModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: ShoelaceModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [
                        AutofocusDirective,
                        OpenableDirective,
                        OpenableExtendedDirective,
                        OpenDirective,
                    ],
                    declarations: [
                        AutofocusDirective,
                        OpenableDirective,
                        OpenableExtendedDirective,
                        OpenDirective,
                    ],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { AutofocusDirective, OpenDirective, OpenableDirective, OpenableExtendedDirective, ShoelaceModule };
//# sourceMappingURL=shoelace-style-angular.mjs.map
