import * as i0 from '@angular/core';
import { forwardRef, Directive, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { not } from 'logical-not';

class FormControlCheckable {
    constructor(hostRef) {
        this.hostRef = hostRef;
    }
    writeValue(checked) {
        this.hostRef.nativeElement.checked = Boolean(checked);
    }
    registerOnChange(callback) {
        const host = this.hostRef.nativeElement;
        host.addEventListener("sl-change", () => {
            if (host.checked)
                callback(host.value || true);
            else
                callback(null);
        });
    }
    registerOnTouched(callback) {
        this.hostRef.nativeElement.addEventListener("sl-blur", callback);
    }
    setDisabledState(disabled) {
        this.hostRef.nativeElement.disabled = disabled;
    }
}
FormControlCheckable.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: FormControlCheckable, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
FormControlCheckable.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.2", type: FormControlCheckable, selector: "\n        sl-checkbox[formControlName],\n        sl-checkbox[formControl],\n        sl-switch[formControlName],\n        sl-switch[formControl],\n    ", providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => FormControlCheckable),
            multi: true,
        },
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: FormControlCheckable, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-checkbox[formControlName],
        sl-checkbox[formControl],
        sl-switch[formControlName],
        sl-switch[formControl],
    `,
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => FormControlCheckable),
                            multi: true,
                        },
                    ],
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; } });

class FormControlColorPicker {
    constructor(hostRef) {
        this.hostRef = hostRef;
        this.inited = false;
        this.initialValue = null;
        setTimeout(() => {
            this.inited = true;
            if (this.initialValue !== null)
                this.writeValue(this.initialValue);
        });
    }
    writeValue(value) {
        if (not(this.inited)) {
            this.initialValue = value;
            return;
        }
        this.hostRef.nativeElement.value = String(value || "");
    }
    registerOnChange(callback) {
        const host = this.hostRef.nativeElement;
        host.addEventListener("sl-change", () => {
            callback(host.value || null);
        });
    }
    registerOnTouched(_) { }
    setDisabledState(disabled) {
        this.hostRef.nativeElement.disabled = disabled;
    }
}
FormControlColorPicker.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: FormControlColorPicker, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
FormControlColorPicker.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.2", type: FormControlColorPicker, selector: "\n        sl-color-picker[formControlName],\n        sl-color-picker[formControl],\n    ", providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => FormControlColorPicker),
            multi: true,
        },
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: FormControlColorPicker, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-color-picker[formControlName],
        sl-color-picker[formControl],
    `,
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => FormControlColorPicker),
                            multi: true,
                        },
                    ],
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; } });

class FormControlNumber {
    constructor(hostRef) {
        this.hostRef = hostRef;
    }
    writeValue(value) {
        if (not(Number.isNaN(value)) && Number.isFinite(value)) {
            this.hostRef.nativeElement.value = String(value);
        }
        else {
            this.hostRef.nativeElement.value = "";
        }
    }
    registerOnChange(callback) {
        const host = this.hostRef.nativeElement;
        const event = host.tagName === "SL-INPUT" ? "sl-input" : "sl-change";
        host.addEventListener(event, () => {
            callback(host.value === "" ? null : parseFloat(host.value));
        });
    }
    registerOnTouched(callback) {
        this.hostRef.nativeElement.addEventListener("sl-blur", callback);
    }
    setDisabledState(disabled) {
        this.hostRef.nativeElement.disabled = disabled;
    }
}
FormControlNumber.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: FormControlNumber, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
FormControlNumber.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.2", type: FormControlNumber, selector: "\n        sl-input[type=number][formControlName],\n        sl-input[type=number][formControl],\n        sl-range[formControlName],\n        sl-range[formControl],\n        sl-rating[formControlName],\n        sl-rating[formControl],\n    ", providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => FormControlNumber),
            multi: true,
        },
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: FormControlNumber, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-input[type=number][formControlName],
        sl-input[type=number][formControl],
        sl-range[formControlName],
        sl-range[formControl],
        sl-rating[formControlName],
        sl-rating[formControl],
    `,
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => FormControlNumber),
                            multi: true,
                        },
                    ],
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; } });

class FormControlInput {
    constructor(hostRef) {
        this.hostRef = hostRef;
    }
    writeValue(value) {
        this.hostRef.nativeElement.value = String(value || "");
    }
    registerOnChange(callback) {
        const host = this.hostRef.nativeElement;
        host.addEventListener("sl-input", () => {
            callback(host.value || null);
        });
    }
    registerOnTouched(callback) {
        this.hostRef.nativeElement.addEventListener("sl-blur", callback);
    }
    setDisabledState(disabled) {
        this.hostRef.nativeElement.disabled = disabled;
    }
}
FormControlInput.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: FormControlInput, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
FormControlInput.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.2", type: FormControlInput, selector: "\n        sl-input:not([type=number])[formControlName],\n        sl-input:not([type=number])[formControl],\n        sl-textarea[formControlName],\n        sl-textarea[formControl],\n    ", providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => FormControlInput),
            multi: true,
        },
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: FormControlInput, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-input:not([type=number])[formControlName],
        sl-input:not([type=number])[formControl],
        sl-textarea[formControlName],
        sl-textarea[formControl],
    `,
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => FormControlInput),
                            multi: true,
                        },
                    ],
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; } });

class FormControlRadio {
    constructor(hostRef) {
        this.hostRef = hostRef;
    }
    writeValue(value) {
        const host = this.hostRef.nativeElement;
        host.value = value;
    }
    registerOnChange(callback) {
        const host = this.hostRef.nativeElement;
        host.addEventListener("sl-change", () => {
            callback(host.value);
        });
    }
    registerOnTouched(callback) {
        this.hostRef.nativeElement.addEventListener("sl-blur", callback);
    }
    setDisabledState(disabled) { }
}
FormControlRadio.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: FormControlRadio, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
FormControlRadio.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.2", type: FormControlRadio, selector: "\n        sl-radio-group[formControlName],\n        sl-radio-group[formControl],\n    ", providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => FormControlRadio),
            multi: true,
        },
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: FormControlRadio, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-radio-group[formControlName],
        sl-radio-group[formControl],
    `,
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => FormControlRadio),
                            multi: true,
                        },
                    ],
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; } });

class FormControlSelect {
    constructor(hostRef) {
        this.hostRef = hostRef;
    }
    writeValue(value) {
        const host = this.hostRef.nativeElement;
        if (host.multiple)
            host.value = Array.isArray(value) ? value : "";
        else
            host.value = String(value || "");
    }
    registerOnChange(callback) {
        const host = this.hostRef.nativeElement;
        host.addEventListener("sl-change", () => {
            callback(host.value || null);
        });
    }
    registerOnTouched(callback) {
        this.hostRef.nativeElement.addEventListener("sl-blur", callback);
    }
    setDisabledState(disabled) {
        this.hostRef.nativeElement.disabled = disabled;
    }
}
FormControlSelect.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: FormControlSelect, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
FormControlSelect.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.2", type: FormControlSelect, selector: "\n        sl-select[formControlName],\n        sl-select[formControl],\n    ", providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => FormControlSelect),
            multi: true,
        },
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: FormControlSelect, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-select[formControlName],
        sl-select[formControl],
    `,
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => FormControlSelect),
                            multi: true,
                        },
                    ],
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; } });

class ShoelaceFormControlsModule {
}
ShoelaceFormControlsModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: ShoelaceFormControlsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ShoelaceFormControlsModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.2", ngImport: i0, type: ShoelaceFormControlsModule, declarations: [FormControlCheckable,
        FormControlColorPicker,
        FormControlInput,
        FormControlNumber,
        FormControlRadio,
        FormControlSelect], exports: [FormControlCheckable,
        FormControlColorPicker,
        FormControlInput,
        FormControlNumber,
        FormControlRadio,
        FormControlSelect] });
ShoelaceFormControlsModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: ShoelaceFormControlsModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: ShoelaceFormControlsModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [
                        FormControlCheckable,
                        FormControlColorPicker,
                        FormControlInput,
                        FormControlNumber,
                        FormControlRadio,
                        FormControlSelect,
                    ],
                    declarations: [
                        FormControlCheckable,
                        FormControlColorPicker,
                        FormControlInput,
                        FormControlNumber,
                        FormControlRadio,
                        FormControlSelect,
                    ],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { FormControlCheckable, FormControlColorPicker, FormControlInput, FormControlNumber, FormControlRadio, FormControlSelect, ShoelaceFormControlsModule };
//# sourceMappingURL=shoelace-style-angular-form-controls.mjs.map
